@@ -27,6 +27,7 @@ from gazoo_device.auxiliary_devices import dli_powerswitch
 from gazoo_device.auxiliary_devices import efr32
 from gazoo_device.auxiliary_devices import efr32_pigweed_lighting
 from gazoo_device.auxiliary_devices import esp32
+from gazoo_device.auxiliary_devices import esp32_pigweed_echo
 from gazoo_device.auxiliary_devices import nrf52840
 from gazoo_device.auxiliary_devices import nrf_pigweed_lighting
 from gazoo_device.auxiliary_devices import raspberry_pi
@@ -43,6 +44,7 @@ from gazoo_device.capabilities import file_transfer_echo
 from gazoo_device.capabilities import file_transfer_scp
 from gazoo_device.capabilities import flash_build_jlink
 from gazoo_device.capabilities import package_management_android
+from gazoo_device.capabilities import pwrpc_button_default
 from gazoo_device.capabilities import pwrpc_common_default
 from gazoo_device.capabilities import pwrpc_echo_default
 from gazoo_device.capabilities import pwrpc_light_default
@@ -60,6 +62,7 @@ from gazoo_device.capabilities.interfaces import fastboot_base
 from gazoo_device.capabilities.interfaces import file_transfer_base
 from gazoo_device.capabilities.interfaces import flash_build_base
 from gazoo_device.capabilities.interfaces import package_management_base
+from gazoo_device.capabilities.interfaces import pwrpc_button_base
 from gazoo_device.capabilities.interfaces import pwrpc_common_base
 from gazoo_device.capabilities.interfaces import pwrpc_echo_base
 from gazoo_device.capabilities.interfaces import pwrpc_light_base
@@ -108,6 +111,7 @@ def export_extensions() -> Dict[str, Any]:
           efr32.EFR32,
           efr32_pigweed_lighting.EFR32PigweedLighting,
           esp32.ESP32,
+          esp32_pigweed_echo.ESP32PigweedEcho,
           nrf52840.NRF52840,
           nrf_pigweed_lighting.NRFPigweedLighting,
           raspberry_pi.RaspberryPi,
@@ -135,6 +139,7 @@ def export_extensions() -> Dict[str, Any]:
           file_transfer_base.FileTransferBase,
           flash_build_base.FlashBuildBase,
           package_management_base.PackageManagementBase,
+          pwrpc_button_base.PwRPCButtonBase,
           pwrpc_common_base.PwRPCCommonBase,
           pwrpc_echo_base.PwRPCEchoBase,
           pwrpc_light_base.PwRPCLightBase,
@@ -155,6 +160,7 @@ def export_extensions() -> Dict[str, Any]:
           file_transfer_scp.FileTransferScp,
           flash_build_jlink.FlashBuildJLink,
           package_management_android.PackageManagementAndroid,
+          pwrpc_button_default.PwRPCButtonDefault,
           pwrpc_common_default.PwRPCCommonDefault,
           pwrpc_echo_default.PwRPCEchoDefault,
           pwrpc_light_default.PwRPCLightDefault,
